@@ -1,6 +1,15 @@
+"""
+OCR-D Command-line interface
+
+.. click:: ocrd.cli:cli
+    :prog: ocrd
+    :nested: short
+"""
 import re
 import click
 
+__all__ = ['cli']
+
 def command_with_replaced_help(*replacements):
 
     class CommandWithReplacedHelp(click.Command):
@@ -18,6 +27,7 @@ from ocrd.cli.workspace import workspace_cli
 from ocrd.cli.process import process_cli
 from ocrd.cli.bashlib import bashlib_cli
 from ocrd.cli.validate import validate_cli
+from ocrd.cli.resmgr import resmgr_cli
 from ocrd.decorators import ocrd_loglevel
 from .zip import zip_cli
 from .log import log_cli
@@ -27,7 +37,7 @@ from .log import log_cli
 @ocrd_loglevel
 def cli(**kwargs): # pylint: disable=unused-argument
     """
-    CLI to OCR-D
+    Entry-point of multi-purpose CLI for OCR-D
     """
 
 cli.add_command(ocrd_tool_cli)
@@ -37,3 +47,4 @@ cli.add_command(bashlib_cli)
 cli.add_command(zip_cli)
 cli.add_command(validate_cli)
 cli.add_command(log_cli)
+cli.add_command(resmgr_cli)
