@@ -107,7 +107,6 @@ class Processor():
                 print(res)
             return
         if show_resource:
-            print(fpath)
             initLogging()
             res_fname = self.resolve_resource(show_resource)
             fpath = Path(res_fname)
@@ -120,8 +119,6 @@ class Processor():
                     copyfileobj(fileobj, sys.stdout.buffer)
             else:
                 sys.stdout.buffer.write(fpath.read_bytes())
-                foo / 0
-                sys.stdout.xxxxflush()
             return
         if show_help:
             self.show_help()
